.. _models:

Models
******

.. currentmodule:: torchkge.models


Translational Models
====================

.. automodule:: torchkge.models.TranslationModels

TransE
------
.. autoclass:: torchkge.models.TranslationModels.TransEModel
   :members:

TransH
------
.. autoclass:: torchkge.models.TranslationModels.TransHModel
   :members:

TransR
------
.. autoclass:: torchkge.models.TranslationModels.TransRModel
   :members:

TransD
------
.. autoclass:: torchkge.models.TranslationModels.TransDModel
   :members:

Semantic Matching Models
========================

.. automodule:: torchkge.models.SemanticMatchingModels

RESCAL
------
.. autoclass:: torchkge.models.SemanticMatchingModels.RESCALModel
   :members:

DistMult
--------
.. autoclass:: torchkge.models.SemanticMatchingModels.DistMultModel
   :members:

HolE
----
.. autoclass:: torchkge.models.SemanticMatchingModels.HolEModel
   :members:

ComplEx
-------
.. autoclass:: torchkge.models.SemanticMatchingModels.ComplExModel
   :members:

ANALOGY
-------
.. autoclass:: torchkge.models.SemanticMatchingModels.AnalogyModel
   :members:
